pub type HeightDiff = i64;Expand description
A difference between two Heights, possibly negative.
This can represent the difference between any height values, even if they are outside the valid height range (for example, in buggy RPC code).
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 8 bytes